@@ -31,8 +31,9 @@ Power.plot <- function(scrfine, WfdList, Qvec, dataList, plotindex=1:n,
     DWvecQ <- rep(0,5)
     for (m in 1:Mi) {
       for (k in 1:5) {
-        DWvecQ[k] <- pracma::interp1(as.numeric(scrfine), as.numeric(DWmatfinei[,m]), 
-                                    as.numeric(Qvec[k]))
+        DWvecQ[k] <- pracma::interp1(as.numeric(scrfine), 
+                                     as.numeric(DWmatfinei[,m]), 
+                                     as.numeric(Qvec[k]))
       }
       powervecQ <- powervecQ + DWvecQ^2
     }
@@ -40,19 +41,26 @@ Power.plot <- function(scrfine, WfdList, Qvec, dataList, plotindex=1:n,
     
     # ggplot version
     
-    default_size=16
+    default_size =16
     default_size1=12
     default_size2=10
     My_Theme <- ggplot2::theme(
-      plot.title = ggplot2::element_text(size = ifelse(is.null(ttlsz),  default_size,ttlsz)),
-      axis.title = ggplot2::element_text(size = ifelse(is.null(axisttl),default_size1,axisttl)),
-      axis.text  = ggplot2::element_text(size = ifelse(is.null(axistxt),default_size2,axistxt)))
+      plot.title = 
+        ggplot2::element_text(size = 
+                                ifelse(is.null(ttlsz),  default_size,ttlsz)),
+      axis.title = 
+        ggplot2::element_text(size = 
+                                ifelse(is.null(axisttl),default_size1,axisttl)),
+      axis.text  = 
+        ggplot2::element_text(size = 
+                                ifelse(is.null(axistxt),default_size2,axistxt)))
     
     df <- data.frame(value=powervec, scrfine=scrfine)
     pp <- ggplot2::ggplot(df, ggplot2::aes(scrfine, powervec)) +
       ggplot2::geom_line(size=linesize, na.rm=TRUE) +
       ggplot2::xlim(plotrange) + ggplot2::ylim(c(0,height)) +
-      ggplot2::geom_vline(xintercept = Qvec, color="black", linetype = "dashed") +
+      ggplot2::geom_vline(xintercept = Qvec, color="black", 
+                          linetype = "dashed") +
       ggplot2::annotate("point", x = Qvec[1], y = powervecQ[1], 
                         colour = "red", size = 1.5) +
       ggplot2::annotate("point", x = Qvec[2], y = powervecQ[2], 
@@ -68,33 +76,27 @@ Power.plot <- function(scrfine, WfdList, Qvec, dataList, plotindex=1:n,
       ggplot2::xlab("Score index") +
       ggplot2::theme(axis.title=ggplot2::element_text(size=16,face="bold"))
     
-    # ----------- Juan Li 2021-02-17 ---------
     if (!is.null(titlestr))
     {
       if (is.null(ItemTitle)) {
         ttllab <- paste('Question ', i, ", total power = ", 
                         round(pracma::trapz(scrfine, powervec),2), sep="")
-      } else 
-      {
+      } else {
         ttllab <- paste('Question ', i,': ',ItemTitle[i], ", total power = ", 
                         round(pracma::trapz(scrfine, powervec),2), sep="") 
-        
       }
     } else {
       if (is.null(ItemTitle)) {
         ttllab <- paste('Question ', i, ", total power = ", 
                         round(pracma::trapz(scrfine, powervec),2), sep="")
-      } else 
-      {
+      } else {
         ttllab <- paste('Question ', i, ': ',ItemTitle[i], ", total power = ", 
                         round(pracma::trapz(scrfine, powervec),2), sep="") 
-        
       }
     }
     
     # -----------------------------------------
     
-    
     pp <- pp + ggplot2::labs(title = ttllab)
     
     print(pp)
@@ -102,28 +104,22 @@ Power.plot <- function(scrfine, WfdList, Qvec, dataList, plotindex=1:n,
     if (length(plotindex) > 1)
     {
       n1<-readline(prompt=
-                     paste("Press [N/n/enter] to next item;",
-                           "[P/p] to previous item; or item index to that item: "))
-      if (n1 == "N" | n1 == "n" | n1 == "")
-      {
+            paste("Press [N/n/enter] to next item;",
+                  "[P/p] to previous item; or item index to that item: "))
+      if (n1 == "N" | n1 == "n" | n1 == "") {
         i = i + 1
-      } else if (n1 == "P" | n1 == "p")
-      {
+      } else if (n1 == "P" | n1 == "p") {
         i = i - 1
-      } else
-      {
+      } else {
         n1 <- suppressWarnings(as.integer(n1))
-        if (!is.na(n1) & (n1 >= plotindex[1] & n1 <= plotindex[length(plotindex)]))
-        {
+        if (!is.na(n1) & (n1 >= plotindex[1] & n1 <= 
+                          plotindex[length(plotindex)])) {
           i <- n1
-        } else
-        {
+        } else {
           break
         }
       }
     }
     gc() # to  free up memory from the previous run
-    
   }
-  
 }
\ No newline at end of file
